@@ -6,7 +6,11 @@ package semver
 
 import "golang.org/x/vuln/internal/osv"
 
-func LatestFixedVersion(ranges []osv.Range) string {
+// NonSupersededFix returns a fixed version from ranges
+// that is not superseded by any other fix or any other
+// introduction of a vulnerability. Returns "" in case
+// there is no such fixed version.
+func NonSupersededFix(ranges []osv.Range) string {
 	var latestFixed string
 	for _, r := range ranges {
 		if r.Type == "SEMVER" {
@@ -16,6 +20,7 @@ func LatestFixedVersion(ranges []osv.Range) string {
 					latestFixed = fixed
 				}
 			}
+
 			// If the vulnerability was re-introduced after the latest fix
 			// we found, there is no latest fix for this range.
 			for _, e := range r.Events {
